;;; idna-mapping.el --- automatically generated (do not edit)   -*- lexical-binding: t -*-
;; Generated by the `unidata-gen-charprop' function.

;; This file is part of GNU Emacs.

;;; Commentary:

;; See the admin/unidata/ directory in the Emacs sources.

;;; Code:

(defconst idna-mapping-table
#^[nil nil nil #^^[3 0 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t nil nil t nil nil nil nil nil nil nil nil nil nil t t t t t t t "a" "b" "c" "d" "e" "f" "g" "h" "i" "j" "k" "l" "m" "n" "o" "p" "q" "r" "s" "t" "u" "v" "w" "x" "y" "z" t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t] #^^[1 0 #^^[2 0 #^^[3 0 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t nil nil t nil nil nil nil nil nil nil nil nil nil t t t t t t t "a" "b" "c" "d" "e" "f" "g" "h" "i" "j" "k" "l" "m" "n" "o" "p" "q" "r" "s" "t" "u" "v" "w" "x" "y" "z" t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t] #^^[3 128 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t nil nil nil nil nil nil nil t nil "a" nil nil ignored nil t nil nil "2" "3" t "μ" nil nil t "1" "o" nil "1⁄4" "1⁄2" "3⁄4" nil "à" "á" "â" "ã" "ä" "å" "æ" "ç" "è" "é" "ê" "ë" "ì" "í" "î" "ï" "ð" "ñ" "ò" "ó" "ô" "õ" "ö" nil "ø" "ù" "ú" "û" "ü" "ý" "þ" nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 256 "ā" nil "ă" nil "ą" nil "ć" nil "ĉ" nil "ċ" nil "č" nil "ď" nil "đ" nil "ē" nil "ĕ" nil "ė" nil "ę" nil "ě" nil "ĝ" nil "ğ" nil "ġ" nil "ģ" nil "ĥ" nil "ħ" nil "ĩ" nil "ī" nil "ĭ" nil "į" nil "i̇" nil "ij" "ij" "ĵ" nil "ķ" nil nil "ĺ" nil "ļ" nil "ľ" nil "l·" "l·" "ł" nil "ń" nil "ņ" nil "ň" nil "ʼn" "ŋ" nil "ō" nil "ŏ" nil "ő" nil "œ" nil "ŕ" nil "ŗ" nil "ř" nil "ś" nil "ŝ" nil "ş" nil "š" nil "ţ" nil "ť" nil "ŧ" nil "ũ" nil "ū" nil "ŭ" nil "ů" nil "ű" nil "ų" nil "ŵ" nil "ŷ" nil "ÿ" "ź" nil "ż" nil "ž" nil "s"] #^^[3 384 nil "ɓ" "ƃ" nil "ƅ" nil "ɔ" "ƈ" nil "ɖ" "ɗ" "ƌ" nil nil "ǝ" "ə" "ɛ" "ƒ" nil "ɠ" "ɣ" nil "ɩ" "ɨ" "ƙ" nil nil nil "ɯ" "ɲ" nil "ɵ" "ơ" nil "ƣ" nil "ƥ" nil "ʀ" "ƨ" nil "ʃ" nil nil "ƭ" nil "ʈ" "ư" nil "ʊ" "ʋ" "ƴ" nil "ƶ" nil "ʒ" "ƹ" nil nil nil "ƽ" nil nil nil nil nil nil nil "dž" "dž" "dž" "lj" "lj" "lj" "nj" "nj" "nj" "ǎ" nil "ǐ" nil "ǒ" nil "ǔ" nil "ǖ" nil "ǘ" nil "ǚ" nil "ǜ" nil nil "ǟ" nil "ǡ" nil "ǣ" nil "ǥ" nil "ǧ" nil "ǩ" nil "ǫ" nil "ǭ" nil "ǯ" nil nil "dz" "dz" "dz" "ǵ" nil "ƕ" "ƿ" "ǹ" nil "ǻ" nil "ǽ" nil "ǿ" nil] #^^[3 512 "ȁ" nil "ȃ" nil "ȅ" nil "ȇ" nil "ȉ" nil "ȋ" nil "ȍ" nil "ȏ" nil "ȑ" nil "ȓ" nil "ȕ" nil "ȗ" nil "ș" nil "ț" nil "ȝ" nil "ȟ" nil "ƞ" nil "ȣ" nil "ȥ" nil "ȧ" nil "ȩ" nil "ȫ" nil "ȭ" nil "ȯ" nil "ȱ" nil "ȳ" nil nil nil nil nil nil nil "ⱥ" "ȼ" nil "ƚ" "ⱦ" nil nil "ɂ" nil "ƀ" "ʉ" "ʌ" "ɇ" nil "ɉ" nil "ɋ" nil "ɍ" nil "ɏ" nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 640 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil "h" "ɦ" "j" "r" "ɹ" "ɻ" "ʁ" "w" "y" nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t nil nil "ɣ" "l" "s" "x" "ʕ" nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 768 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil "̀" "́" nil "̓" "̈́" "ι" nil nil nil nil nil nil nil nil nil ignored nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil "ͱ" nil "ͳ" nil "ʹ" nil "ͷ" nil t t t nil nil nil t "ϳ"] #^^[3 896 t t t t t t "ά" "·" "έ" "ή" "ί" t "ό" t "ύ" "ώ" nil "α" "β" "γ" "δ" "ε" "ζ" "η" "θ" "ι" "κ" "λ" "μ" "ν" "ξ" "ο" "π" "ρ" t "σ" "τ" "υ" "φ" "χ" "ψ" "ω" "ϊ" "ϋ" nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil "ϗ" "β" "θ" "υ" "ύ" "ϋ" "φ" "π" nil "ϙ" nil "ϛ" nil "ϝ" nil "ϟ" nil "ϡ" nil "ϣ" nil "ϥ" nil "ϧ" nil "ϩ" nil "ϫ" nil "ϭ" nil "ϯ" nil "κ" "ρ" "σ" nil "θ" "ε" nil "ϸ" nil "σ" "ϻ" nil nil "ͻ" "ͼ" "ͽ"] #^^[3 1024 "ѐ" "ё" "ђ" "ѓ" "є" "ѕ" "і" "ї" "ј" "љ" "њ" "ћ" "ќ" "ѝ" "ў" "џ" "а" "б" "в" "г" "д" "е" "ж" "з" "и" "й" "к" "л" "м" "н" "о" "п" "р" "с" "т" "у" "ф" "х" "ц" "ч" "ш" "щ" "ъ" "ы" "ь" "э" "ю" "я" nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil "ѡ" nil "ѣ" nil "ѥ" nil "ѧ" nil "ѩ" nil "ѫ" nil "ѭ" nil "ѯ" nil "ѱ" nil "ѳ" nil "ѵ" nil "ѷ" nil "ѹ" nil "ѻ" nil "ѽ" nil "ѿ" nil] #^^[3 1152 "ҁ" nil nil nil nil nil nil nil nil nil "ҋ" nil "ҍ" nil "ҏ" nil "ґ" nil "ғ" nil "ҕ" nil "җ" nil "ҙ" nil "қ" nil "ҝ" nil "ҟ" nil "ҡ" nil "ң" nil "ҥ" nil "ҧ" nil "ҩ" nil "ҫ" nil "ҭ" nil "ү" nil "ұ" nil "ҳ" nil "ҵ" nil "ҷ" nil "ҹ" nil "һ" nil "ҽ" nil "ҿ" nil t "ӂ" nil "ӄ" nil "ӆ" nil "ӈ" nil "ӊ" nil "ӌ" nil "ӎ" nil nil "ӑ" nil "ӓ" nil "ӕ" nil "ӗ" nil "ә" nil "ӛ" nil "ӝ" nil "ӟ" nil "ӡ" nil "ӣ" nil "ӥ" nil "ӧ" nil "ө" nil "ӫ" nil "ӭ" nil "ӯ" nil "ӱ" nil "ӳ" nil "ӵ" nil "ӷ" nil "ӹ" nil "ӻ" nil "ӽ" nil "ӿ" nil] #^^[3 1280 "ԁ" nil "ԃ" nil "ԅ" nil "ԇ" nil "ԉ" nil "ԋ" nil "ԍ" nil "ԏ" nil "ԑ" nil "ԓ" nil "ԕ" nil "ԗ" nil "ԙ" nil "ԛ" nil "ԝ" nil "ԟ" nil "ԡ" nil "ԣ" nil "ԥ" nil "ԧ" nil "ԩ" nil "ԫ" nil "ԭ" nil "ԯ" nil t "ա" "բ" "գ" "դ" "ե" "զ" "է" "ը" "թ" "ժ" "ի" "լ" "խ" "ծ" "կ" "հ" "ձ" "ղ" "ճ" "մ" "յ" "ն" "շ" "ո" "չ" "պ" "ջ" "ռ" "ս" "վ" "տ" "ր" "ց" "ւ" "փ" "ք" "օ" "ֆ" t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 1408 nil nil nil nil nil nil nil "եւ" nil nil nil t t nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t nil nil nil nil nil nil t t t t t t t t t t t] #^^[3 1536 t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil "اٴ" "وٴ" "ۇٴ" "يٴ" nil nil nil nil nil nil nil] #^^[3 1664 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 1792 nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 1920 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil nil] #^^[3 2048 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil t nil nil nil nil nil nil nil nil nil nil nil t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 2176 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 2304 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil "क़" "ख़" "ग़" "ज़" "ड़" "ढ़" "फ़" "य़" nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 2432 nil nil nil nil t nil nil nil nil nil nil nil nil t t nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil t nil t t t nil nil nil nil t t nil nil nil nil nil nil nil nil nil t t nil nil t t nil nil nil nil t t t t t t t t nil t t t t "ড়" "ঢ়" t "য়" nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t] #^^[3 2560 t nil nil nil t nil nil nil nil nil nil t t t t nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil t nil "ਲ਼" t nil "ਸ਼" t nil nil t t nil t nil nil nil nil nil t t t t nil nil t t nil nil nil t t t nil t t t t t t t "ਖ਼" "ਗ਼" "ਜ਼" nil t "ਫ਼" t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t] #^^[3 2688 t nil nil nil t nil nil nil nil nil nil nil nil nil t nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil t nil nil t nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil t nil nil nil t nil nil nil t t nil t t t t t t t t t t t t t t t nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t nil nil nil nil nil nil nil] #^^[3 2816 t nil nil nil t nil nil nil nil nil nil nil nil t t nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil t nil nil t nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil t t nil nil t t nil nil nil t t t t t t t nil nil nil t t t t "ଡ଼" "ଢ଼" t nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t] #^^[3 2944 t t nil nil t nil nil nil nil nil nil t t t nil nil nil t nil nil nil nil t t t nil nil t nil t nil nil t t t nil nil t t t nil nil nil t t t nil nil nil nil nil nil nil nil nil nil nil nil t t t t nil nil nil nil nil t t t nil nil nil t nil nil nil nil t t nil t t t t t t nil t t t t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t] #^^[3 3072 nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil t nil nil nil t nil nil nil nil t t t t t t t nil nil t nil nil nil t t nil t t nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil t t t t t t t nil nil nil nil nil nil nil nil nil] #^^[3 3200 nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil t nil nil nil t nil nil nil nil t t t t t t t nil nil t t t t t t nil nil t nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil t nil nil nil t t t t t t t t t t t t] #^^[3 3328 nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil t nil nil nil nil nil nil t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 3456 t nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil t nil t t nil nil nil nil nil nil nil t t t nil t t t t nil nil nil nil nil nil t nil t nil nil nil nil nil nil nil nil t t t t t t nil nil nil nil nil nil nil nil nil nil t t nil nil nil t t t t t t t t t t t] #^^[3 3584 t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil "ํา" nil nil nil nil nil nil nil t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] #^^[3 3712 t nil nil t nil t nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil t nil nil nil nil nil nil nil nil nil nil nil nil "ໍາ" nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil nil t nil t nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil t t "ຫນ" "ຫມ" nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] #^^[3 3840 nil nil nil nil nil nil nil nil nil nil nil nil "་" nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil "གྷ" nil nil nil nil t nil nil nil nil "ཌྷ" nil nil nil nil "དྷ" nil nil nil nil "བྷ" nil nil nil nil "ཛྷ" nil nil nil nil nil nil nil nil nil nil nil nil "ཀྵ" nil nil nil t t t t nil nil "ཱི" nil "ཱུ" "ྲྀ" "ྲཱྀ" "ླྀ" "ླཱྀ" nil nil nil nil nil nil] #^^[3 3968 nil "ཱྀ" nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil "ྒྷ" nil nil nil nil t nil nil nil nil "ྜྷ" nil nil nil nil "ྡྷ" nil nil nil nil "ྦྷ" nil nil nil nil "ྫྷ" nil nil nil nil nil nil nil nil nil nil nil nil "ྐྵ" nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t]] #^^[2 4096 nil #^^[3 4224 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t "ⴧ" t t t t t "ⴭ" t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil "ნ" nil nil nil] #^^[3 4352 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] nil #^^[3 4608 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil t t nil nil nil nil nil nil nil t nil t nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 4736 nil nil nil nil nil nil nil nil nil t nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil t t nil nil nil nil nil nil nil t nil t nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 4864 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t] #^^[3 4992 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t "Ᏸ" "Ᏹ" "Ᏺ" "Ᏻ" "Ᏼ" "Ᏽ" t t] nil nil nil nil nil #^^[3 5760 t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t] #^^[3 5888 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil t nil nil t t t t t t t t t t t t] #^^[3 6016 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil t t t t t t nil nil nil nil nil nil nil nil nil nil t t t t t t] #^^[3 6144 nil nil nil nil nil nil t nil nil nil nil ignored ignored ignored t ignored nil nil nil nil nil nil nil nil nil nil t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t] #^^[3 6272 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t] #^^[3 6400 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil t t t t nil nil nil nil nil nil nil nil nil nil nil nil t t t t nil t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil nil t t t t t t t t t t t] #^^[3 6528 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t nil nil nil nil nil nil nil nil nil nil nil t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 6656 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil] #^^[3 6784 nil nil nil nil nil nil nil nil nil nil t t t t t t nil nil nil nil nil nil nil nil nil nil t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] #^^[3 6912 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t] #^^[3 7040 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t nil nil nil nil] #^^[3 7168 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 7296 "в" "д" "о" "с" "т" "т" "ъ" "ѣ" "ꙋ" t t t t t t t "ა" "ბ" "გ" "დ" "ე" "ვ" "ზ" "თ" "ი" "კ" "ლ" "მ" "ნ" "ო" "პ" "ჟ" "რ" "ს" "ტ" "უ" "ფ" "ქ" "ღ" "ყ" "შ" "ჩ" "ც" "ძ" "წ" "ჭ" "ხ" "ჯ" "ჰ" "ჱ" "ჲ" "ჳ" "ჴ" "ჵ" "ჶ" "ჷ" "ჸ" "ჹ" "ჺ" t t "ჽ" "ჾ" "ჿ" nil nil nil nil nil nil nil nil t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t] #^^[3 7424 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil "a" "æ" "b" nil "d" "e" "ǝ" "g" "h" "i" "j" "k" "l" "m" "n" nil "o" "ȣ" "p" "r" "t" "u" "w" "a" "ɐ" "ɑ" "ᴂ" "b" "d" "e" "ə" "ɛ" "ɜ" "g" nil "k" "m" "ŋ" "o" "ɔ" "ᴖ" "ᴗ" "p" "t" "u" "ᴝ" "ɯ" "v" "ᴥ" "β" "γ" "δ" "φ" "χ" "i" "r" "u" "v" "β" "γ" "ρ" "φ" "χ" nil nil nil nil nil nil nil nil nil nil nil nil nil "н" nil nil nil nil nil nil nil] #^^[3 7552 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil "ɒ" "c" "ɕ" "ð" "ɜ" "f" "ɟ" "ɡ" "ɥ" "ɨ" "ɩ" "ɪ" "ᵻ" "ʝ" "ɭ" "ᶅ" "ʟ" "ɱ" "ɰ" "ɲ" "ɳ" "ɴ" "ɵ" "ɸ" "ʂ" "ʃ" "ƫ" "ʉ" "ʊ" "ᴜ" "ʋ" "ʌ" "z" "ʐ" "ʑ" "ʒ" "θ" nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 7680 "ḁ" nil "ḃ" nil "ḅ" nil "ḇ" nil "ḉ" nil "ḋ" nil "ḍ" nil "ḏ" nil "ḑ" nil "ḓ" nil "ḕ" nil "ḗ" nil "ḙ" nil "ḛ" nil "ḝ" nil "ḟ" nil "ḡ" nil "ḣ" nil "ḥ" nil "ḧ" nil "ḩ" nil "ḫ" nil "ḭ" nil "ḯ" nil "ḱ" nil "ḳ" nil "ḵ" nil "ḷ" nil "ḹ" nil "ḻ" nil "ḽ" nil "ḿ" nil "ṁ" nil "ṃ" nil "ṅ" nil "ṇ" nil "ṉ" nil "ṋ" nil "ṍ" nil "ṏ" nil "ṑ" nil "ṓ" nil "ṕ" nil "ṗ" nil "ṙ" nil "ṛ" nil "ṝ" nil "ṟ" nil "ṡ" nil "ṣ" nil "ṥ" nil "ṧ" nil "ṩ" nil "ṫ" nil "ṭ" nil "ṯ" nil "ṱ" nil "ṳ" nil "ṵ" nil "ṷ" nil "ṹ" nil "ṻ" nil "ṽ" nil "ṿ" nil] #^^[3 7808 "ẁ" nil "ẃ" nil "ẅ" nil "ẇ" nil "ẉ" nil "ẋ" nil "ẍ" nil "ẏ" nil "ẑ" nil "ẓ" nil "ẕ" nil nil nil nil nil "aʾ" "ṡ" nil nil "ß" nil "ạ" nil "ả" nil "ấ" nil "ầ" nil "ẩ" nil "ẫ" nil "ậ" nil "ắ" nil "ằ" nil "ẳ" nil "ẵ" nil "ặ" nil "ẹ" nil "ẻ" nil "ẽ" nil "ế" nil "ề" nil "ể" nil "ễ" nil "ệ" nil "ỉ" nil "ị" nil "ọ" nil "ỏ" nil "ố" nil "ồ" nil "ổ" nil "ỗ" nil "ộ" nil "ớ" nil "ờ" nil "ở" nil "ỡ" nil "ợ" nil "ụ" nil "ủ" nil "ứ" nil "ừ" nil "ử" nil "ữ" nil "ự" nil "ỳ" nil "ỵ" nil "ỷ" nil "ỹ" nil "ỻ" nil "ỽ" nil "ỿ" nil] #^^[3 7936 nil nil nil nil nil nil nil nil "ἀ" "ἁ" "ἂ" "ἃ" "ἄ" "ἅ" "ἆ" "ἇ" nil nil nil nil nil nil t t "ἐ" "ἑ" "ἒ" "ἓ" "ἔ" "ἕ" t t nil nil nil nil nil nil nil nil "ἠ" "ἡ" "ἢ" "ἣ" "ἤ" "ἥ" "ἦ" "ἧ" nil nil nil nil nil nil nil nil "ἰ" "ἱ" "ἲ" "ἳ" "ἴ" "ἵ" "ἶ" "ἷ" nil nil nil nil nil nil t t "ὀ" "ὁ" "ὂ" "ὃ" "ὄ" "ὅ" t t nil nil nil nil nil nil nil nil t "ὑ" t "ὓ" t "ὕ" t "ὗ" nil nil nil nil nil nil nil nil "ὠ" "ὡ" "ὢ" "ὣ" "ὤ" "ὥ" "ὦ" "ὧ" nil "ά" nil "έ" nil "ή" nil "ί" nil "ό" nil "ύ" nil "ώ" t t] #^^[3 8064 "ἀι" "ἁι" "ἂι" "ἃι" "ἄι" "ἅι" "ἆι" "ἇι" "ἀι" "ἁι" "ἂι" "ἃι" "ἄι" "ἅι" "ἆι" "ἇι" "ἠι" "ἡι" "ἢι" "ἣι" "ἤι" "ἥι" "ἦι" "ἧι" "ἠι" "ἡι" "ἢι" "ἣι" "ἤι" "ἥι" "ἦι" "ἧι" "ὠι" "ὡι" "ὢι" "ὣι" "ὤι" "ὥι" "ὦι" "ὧι" "ὠι" "ὡι" "ὢι" "ὣι" "ὤι" "ὥι" "ὦι" "ὧι" nil nil "ὰι" "αι" "άι" t nil "ᾶι" "ᾰ" "ᾱ" "ὰ" "ά" "αι" t "ι" t t t "ὴι" "ηι" "ήι" t nil "ῆι" "ὲ" "έ" "ὴ" "ή" "ηι" t t t nil nil nil "ΐ" t t nil nil "ῐ" "ῑ" "ὶ" "ί" t t t t nil nil nil "ΰ" nil nil nil nil "ῠ" "ῡ" "ὺ" "ύ" "ῥ" t t t t t "ὼι" "ωι" "ώι" t nil "ῶι" "ὸ" "ό" "ὼ" "ώ" "ωι" t t t]] #^^[2 8192 #^^[3 8192 t t t t t t t t t t t ignored nil nil t t nil "‐" nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil t t t nil t t t t t t t t nil nil nil "′′" "′′′" nil "‵‵" "‵‵‵" nil nil nil nil t nil t nil nil nil nil nil nil nil nil t t t nil nil nil nil nil nil nil nil nil nil nil nil nil "′′′′" nil nil nil nil nil nil nil t ignored t t t ignored t t t t t t t t t t t "0" "i" t t "4" "5" "6" "7" "8" "9" t "−" t t t "n"] #^^[3 8320 "0" "1" "2" "3" "4" "5" "6" "7" "8" "9" t "−" t t t t "a" "e" "o" "x" "ə" "h" "k" "l" "m" "n" "p" "s" "t" t t t nil nil nil nil nil nil nil nil "rs" nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t] #^^[3 8448 t t "c" "°c" nil t t "ɛ" nil "°f" "g" "h" "h" "h" "h" "ħ" "i" "i" "l" "l" nil "n" "no" nil nil "p" "q" "r" "r" "r" nil nil "sm" "tel" "tm" nil "z" nil "ω" nil "z" nil "k" "å" "b" "c" nil "e" "e" "f" t "m" "o" "א" "ב" "ג" "ד" "i" nil "fax" "π" "γ" "γ" "π" "∑" nil nil nil nil "d" "d" "e" "i" "j" nil nil nil nil nil nil "1⁄7" "1⁄9" "1⁄10" "1⁄3" "2⁄3" "1⁄5" "2⁄5" "3⁄5" "4⁄5" "1⁄6" "5⁄6" "1⁄8" "3⁄8" "5⁄8" "7⁄8" "1⁄" "i" "ii" "iii" "iv" "v" "vi" "vii" "viii" "ix" "x" "xi" "xii" "l" "c" "d" "m" "i" "ii" "iii" "iv" "v" "vi" "vii" "viii" "ix" "x" "xi" "xii" "l" "c" "d" "m"] #^^[3 8576 nil nil nil t nil nil nil nil nil "0⁄3" nil nil t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 8704 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil "∫∫" "∫∫∫" nil "∮∮" "∮∮∮" nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] nil #^^[3 8960 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil "〈" "〉" nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] nil #^^[3 9216 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t "1" "2" "3" "4" "5" "6" "7" "8" "9" "10" "11" "12" "13" "14" "15" "16" "17" "18" "19" "20" t t t t t t t t t t t t] #^^[3 9344 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t "a" "b" "c" "d" "e" "f" "g" "h" "i" "j" "k" "l" "m" "n" "o" "p" "q" "r" "s" "t" "u" "v" "w" "x" "y" "z" "a" "b" "c" "d" "e" "f" "g" "h" "i" "j" "k" "l" "m" "n" "o" "p" "q" "r" "s" "t" "u" "v" "w" "x" "y" "z" "0" nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] nil nil nil nil nil nil nil nil nil nil #^^[3 10752 nil nil nil nil nil nil nil nil nil nil nil nil "∫∫∫∫" nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t nil nil nil nil nil nil nil nil nil] #^^[3 10880 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil "⫝̸" nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 11008 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil] #^^[3 11136 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 11264 "ⰰ" "ⰱ" "ⰲ" "ⰳ" "ⰴ" "ⰵ" "ⰶ" "ⰷ" "ⰸ" "ⰹ" "ⰺ" "ⰻ" "ⰼ" "ⰽ" "ⰾ" "ⰿ" "ⱀ" "ⱁ" "ⱂ" "ⱃ" "ⱄ" "ⱅ" "ⱆ" "ⱇ" "ⱈ" "ⱉ" "ⱊ" "ⱋ" "ⱌ" "ⱍ" "ⱎ" "ⱏ" "ⱐ" "ⱑ" "ⱒ" "ⱓ" "ⱔ" "ⱕ" "ⱖ" "ⱗ" "ⱘ" "ⱙ" "ⱚ" "ⱛ" "ⱜ" "ⱝ" "ⱞ" "ⱟ" nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil "ⱡ" nil "ɫ" "ᵽ" "ɽ" nil nil "ⱨ" nil "ⱪ" nil "ⱬ" nil "ɑ" "ɱ" "ɐ" "ɒ" nil "ⱳ" nil nil "ⱶ" nil nil nil nil nil nil "j" "v" "ȿ" "ɀ"] #^^[3 11392 "ⲁ" nil "ⲃ" nil "ⲅ" nil "ⲇ" nil "ⲉ" nil "ⲋ" nil "ⲍ" nil "ⲏ" nil "ⲑ" nil "ⲓ" nil "ⲕ" nil "ⲗ" nil "ⲙ" nil "ⲛ" nil "ⲝ" nil "ⲟ" nil "ⲡ" nil "ⲣ" nil "ⲥ" nil "ⲧ" nil "ⲩ" nil "ⲫ" nil "ⲭ" nil "ⲯ" nil "ⲱ" nil "ⲳ" nil "ⲵ" nil "ⲷ" nil "ⲹ" nil "ⲻ" nil "ⲽ" nil "ⲿ" nil "ⳁ" nil "ⳃ" nil "ⳅ" nil "ⳇ" nil "ⳉ" nil "ⳋ" nil "ⳍ" nil "ⳏ" nil "ⳑ" nil "ⳓ" nil "ⳕ" nil "ⳗ" nil "ⳙ" nil "ⳛ" nil "ⳝ" nil "ⳟ" nil "ⳡ" nil "ⳣ" nil nil nil nil nil nil nil nil "ⳬ" nil "ⳮ" nil nil nil nil "ⳳ" nil t t t t t nil nil nil nil nil nil nil] #^^[3 11520 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil t t t t t nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t "ⵡ" nil t t t t t t t t t t t t t t nil] #^^[3 11648 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t nil nil nil nil nil nil nil t nil nil nil nil nil nil nil t nil nil nil nil nil nil nil t nil nil nil nil nil nil nil t nil nil nil nil nil nil nil t nil nil nil nil nil nil nil t nil nil nil nil nil nil nil t nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 11776 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] #^^[3 11904 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil "母" nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil "龟" t t t t t t t t t t t t] #^^[3 12032 "一" "丨" "丶" "丿" "乙" "亅" "二" "亠" "人" "儿" "入" "八" "冂" "冖" "冫" "几" "凵" "刀" "力" "勹" "匕" "匚" "匸" "十" "卜" "卩" "厂" "厶" "又" "口" "囗" "土" "士" "夂" "夊" "夕" "大" "女" "子" "宀" "寸" "小" "尢" "尸" "屮" "山" "巛" "工" "己" "巾" "干" "幺" "广" "廴" "廾" "弋" "弓" "彐" "彡" "彳" "心" "戈" "戶" "手" "支" "攴" "文" "斗" "斤" "方" "无" "日" "曰" "月" "木" "欠" "止" "歹" "殳" "毋" "比" "毛" "氏" "气" "水" "火" "爪" "父" "爻" "爿" "片" "牙" "牛" "犬" "玄" "玉" "瓜" "瓦" "甘" "生" "用" "田" "疋" "疒" "癶" "白" "皮" "皿" "目" "矛" "矢" "石" "示" "禸" "禾" "穴" "立" "竹" "米" "糸" "缶" "网" "羊" "羽" "老" "而" "耒" "耳"] #^^[3 12160 "聿" "肉" "臣" "自" "至" "臼" "舌" "舛" "舟" "艮" "色" "艸" "虍" "虫" "血" "行" "衣" "襾" "見" "角" "言" "谷" "豆" "豕" "豸" "貝" "赤" "走" "足" "身" "車" "辛" "辰" "辵" "邑" "酉" "釆" "里" "金" "長" "門" "阜" "隶" "隹" "雨" "靑" "非" "面" "革" "韋" "韭" "音" "頁" "風" "飛" "食" "首" "香" "馬" "骨" "高" "髟" "鬥" "鬯" "鬲" "鬼" "魚" "鳥" "鹵" "鹿" "麥" "麻" "黃" "黍" "黑" "黹" "黽" "鼎" "鼓" "鼠" "鼻" "齊" "齒" "龍" "龜" "龠" t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t]] #^^[2 12288 #^^[3 12288 t nil "." nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil "〒" nil "十" "卄" "卅" nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 12416 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil t t nil nil "より" nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil "コト"] #^^[3 12544 t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t "ᄀ" "ᄁ" "ᆪ" "ᄂ" "ᆬ" "ᆭ" "ᄃ" "ᄄ" "ᄅ" "ᆰ" "ᆱ" "ᆲ" "ᆳ" "ᆴ" "ᆵ" "ᄚ" "ᄆ" "ᄇ" "ᄈ" "ᄡ" "ᄉ" "ᄊ" "ᄋ" "ᄌ" "ᄍ" "ᄎ" "ᄏ" "ᄐ" "ᄑ" "ᄒ" "ᅡ" "ᅢ" "ᅣ" "ᅤ" "ᅥ" "ᅦ" "ᅧ" "ᅨ" "ᅩ" "ᅪ" "ᅫ" "ᅬ" "ᅭ" "ᅮ" "ᅯ" "ᅰ" "ᅱ" "ᅲ" "ᅳ" "ᅴ" "ᅵ" t "ᄔ" "ᄕ" "ᇇ" "ᇈ" "ᇌ" "ᇎ" "ᇓ" "ᇗ" "ᇙ" "ᄜ" "ᇝ" "ᇟ" "ᄝ" "ᄞ" "ᄠ" "ᄢ" "ᄣ" "ᄧ" "ᄩ" "ᄫ" "ᄬ" "ᄭ" "ᄮ" "ᄯ" "ᄲ" "ᄶ" "ᅀ"] #^^[3 12672 "ᅇ" "ᅌ" "ᇱ" "ᇲ" "ᅗ" "ᅘ" "ᅙ" "ᆄ" "ᆅ" "ᆈ" "ᆑ" "ᆒ" "ᆔ" "ᆞ" "ᆡ" t nil nil "一" "二" "三" "四" "上" "中" "下" "甲" "乙" "丙" "丁" "天" "地" "人" nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 12800 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t "問" "幼" "文" "箏" nil nil nil nil nil nil nil nil "pte" "21" "22" "23" "24" "25" "26" "27" "28" "29" "30" "31" "32" "33" "34" "35" "ᄀ" "ᄂ" "ᄃ" "ᄅ" "ᄆ" "ᄇ" "ᄉ" "ᄋ" "ᄌ" "ᄎ" "ᄏ" "ᄐ" "ᄑ" "ᄒ" "가" "나" "다" "라" "마" "바" "사" "아" "자" "차" "카" "타" "파" "하" "참고" "주의" "우" nil] #^^[3 12928 "一" "二" "三" "四" "五" "六" "七" "八" "九" "十" "月" "火" "水" "木" "金" "土" "日" "株" "有" "社" "名" "特" "財" "祝" "労" "秘" "男" "女" "適" "優" "印" "注" "項" "休" "写" "正" "上" "中" "下" "左" "右" "医" "宗" "学" "監" "企" "資" "協" "夜" "36" "37" "38" "39" "40" "41" "42" "43" "44" "45" "46" "47" "48" "49" "50" "1月" "2月" "3月" "4月" "5月" "6月" "7月" "8月" "9月" "10月" "11月" "12月" "hg" "erg" "ev" "ltd" "ア" "イ" "ウ" "エ" "オ" "カ" "キ" "ク" "ケ" "コ" "サ" "シ" "ス" "セ" "ソ" "タ" "チ" "ツ" "テ" "ト" "ナ" "ニ" "ヌ" "ネ" "ノ" "ハ" "ヒ" "フ" "ヘ" "ホ" "マ" "ミ" "ム" "メ" "モ" "ヤ" "ユ" "ヨ" "ラ" "リ" "ル" "レ" "ロ" "ワ" "ヰ" "ヱ" "ヲ" "令和"] #^^[3 13056 "アパート" "アルファ" "アンペア" "アール" "イニング" "インチ" "ウォン" "エスクード" "エーカー" "オンス" "オーム" "カイリ" "カラット" "カロリー" "ガロン" "ガンマ" "ギガ" "ギニー" "キュリー" "ギルダー" "キロ" "キログラム" "キロメートル" "キロワット" "グラム" "グラムトン" "クルゼイロ" "クローネ" "ケース" "コルナ" "コーポ" "サイクル" "サンチーム" "シリング" "センチ" "セント" "ダース" "デシ" "ドル" "トン" "ナノ" "ノット" "ハイツ" "パーセント" "パーツ" "バーレル" "ピアストル" "ピクル" "ピコ" "ビル" "ファラッド" "フィート" "ブッシェル" "フラン" "ヘクタール" "ペソ" "ペニヒ" "ヘルツ" "ペンス" "ページ" "ベータ" "ポイント" "ボルト" "ホン" "ポンド" "ホール" "ホーン" "マイクロ" "マイル" "マッハ" "マルク" "マンション" "ミクロン" "ミリ" "ミリバール" "メガ" "メガトン" "メートル" "ヤード" "ヤール" "ユアン" "リットル" "リラ" "ルピー" "ルーブル" "レム" "レントゲン" "ワット" "0点" "1点" "2点" "3点" "4点" "5点" "6点" "7点" "8点" "9点" "10点" "11点" "12点" "13点" "14点" "15点" "16点" "17点" "18点" "19点" "20点" "21点" "22点" "23点" "24点" "hpa" "da" "au" "bar" "ov" "pc" "dm" "dm2" "dm3" "iu" "平成" "昭和" "大正" "明治" "株式会社"] #^^[3 13184 "pa" "na" "μa" "ma" "ka" "kb" "mb" "gb" "cal" "kcal" "pf" "nf" "μf" "μg" "mg" "kg" "hz" "khz" "mhz" "ghz" "thz" "μl" "ml" "dl" "kl" "fm" "nm" "μm" "mm" "cm" "km" "mm2" "cm2" "m2" "km2" "mm3" "cm3" "m3" "km3" "m∕s" "m∕s2" "pa" "kpa" "mpa" "gpa" "rad" "rad∕s" "rad∕s2" "ps" "ns" "μs" "ms" "pv" "nv" "μv" "mv" "kv" "mv" "pw" "nw" "μw" "mw" "kw" "mw" "kω" "mω" t "bq" "cc" "cd" "c∕kg" t "db" "gy" "ha" "hp" "in" "kk" "km" "kt" "lm" "ln" "log" "lx" "mb" "mil" "mol" "ph" t "ppm" "pr" "sr" "sv" "wb" "v∕m" "a∕m" "1日" "2日" "3日" "4日" "5日" "6日" "7日" "8日" "9日" "10日" "11日" "12日" "13日" "14日" "15日" "16日" "17日" "18日" "19日" "20日" "21日" "22日" "23日" "24日" "25日" "26日" "27日" "28日" "29日" "30日" "31日" "gal"] nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] nil nil nil nil nil nil #^^[2 40960 nil nil nil nil nil nil nil nil nil #^^[3 42112 nil nil nil nil nil nil nil nil nil nil nil nil nil t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] nil nil #^^[3 42496 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t "ꙁ" nil "ꙃ" nil "ꙅ" nil "ꙇ" nil "ꙉ" nil "ꙋ" nil "ꙍ" nil "ꙏ" nil "ꙑ" nil "ꙓ" nil "ꙕ" nil "ꙗ" nil "ꙙ" nil "ꙛ" nil "ꙝ" nil "ꙟ" nil "ꙡ" nil "ꙣ" nil "ꙥ" nil "ꙧ" nil "ꙩ" nil "ꙫ" nil "ꙭ" nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 42624 "ꚁ" nil "ꚃ" nil "ꚅ" nil "ꚇ" nil "ꚉ" nil "ꚋ" nil "ꚍ" nil "ꚏ" nil "ꚑ" nil "ꚓ" nil "ꚕ" nil "ꚗ" nil "ꚙ" nil "ꚛ" nil "ъ" "ь" nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t] #^^[3 42752 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil "ꜣ" nil "ꜥ" nil "ꜧ" nil "ꜩ" nil "ꜫ" nil "ꜭ" nil "ꜯ" nil nil nil "ꜳ" nil "ꜵ" nil "ꜷ" nil "ꜹ" nil "ꜻ" nil "ꜽ" nil "ꜿ" nil "ꝁ" nil "ꝃ" nil "ꝅ" nil "ꝇ" nil "ꝉ" nil "ꝋ" nil "ꝍ" nil "ꝏ" nil "ꝑ" nil "ꝓ" nil "ꝕ" nil "ꝗ" nil "ꝙ" nil "ꝛ" nil "ꝝ" nil "ꝟ" nil "ꝡ" nil "ꝣ" nil "ꝥ" nil "ꝧ" nil "ꝩ" nil "ꝫ" nil "ꝭ" nil "ꝯ" nil "ꝯ" nil nil nil nil nil nil nil nil "ꝺ" nil "ꝼ" nil "ᵹ" "ꝿ" nil] #^^[3 42880 "ꞁ" nil "ꞃ" nil "ꞅ" nil "ꞇ" nil nil nil nil "ꞌ" nil "ɥ" nil nil "ꞑ" nil "ꞓ" nil nil nil "ꞗ" nil "ꞙ" nil "ꞛ" nil "ꞝ" nil "ꞟ" nil "ꞡ" nil "ꞣ" nil "ꞥ" nil "ꞧ" nil "ꞩ" nil "ɦ" "ɜ" "ɡ" "ɬ" "ɪ" nil "ʞ" "ʇ" "ʝ" "ꭓ" "ꞵ" nil "ꞷ" nil "ꞹ" nil "ꞻ" nil "ꞽ" nil "ꞿ" nil "ꟁ" nil "ꟃ" nil "ꞔ" "ʂ" "ᶎ" "ꟈ" nil "ꟊ" nil t t t t t "ꟑ" nil t nil t nil "ꟗ" nil "ꟙ" nil t t t t t t t t t t t t t t t t t t t t t t t t "c" "f" "q" "ꟶ" nil nil "ħ" "œ" nil nil nil nil nil nil] #^^[3 43008 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t nil nil nil nil nil nil nil nil nil nil t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t] #^^[3 43136 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 43264 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t] #^^[3 43392 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t] #^^[3 43520 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 43648 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t] #^^[3 43776 t nil nil nil nil nil nil t t nil nil nil nil nil nil t t nil nil nil nil nil nil t t t t t t t t t nil nil nil nil nil nil nil t nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil "ꜧ" "ꬷ" "ɫ" "ꭒ" nil nil nil nil nil nil nil nil nil "ʍ" nil nil t t t t "Ꭰ" "Ꭱ" "Ꭲ" "Ꭳ" "Ꭴ" "Ꭵ" "Ꭶ" "Ꭷ" "Ꭸ" "Ꭹ" "Ꭺ" "Ꭻ" "Ꭼ" "Ꭽ" "Ꭾ" "Ꭿ"] #^^[3 43904 "Ꮀ" "Ꮁ" "Ꮂ" "Ꮃ" "Ꮄ" "Ꮅ" "Ꮆ" "Ꮇ" "Ꮈ" "Ꮉ" "Ꮊ" "Ꮋ" "Ꮌ" "Ꮍ" "Ꮎ" "Ꮏ" "Ꮐ" "Ꮑ" "Ꮒ" "Ꮓ" "Ꮔ" "Ꮕ" "Ꮖ" "Ꮗ" "Ꮘ" "Ꮙ" "Ꮚ" "Ꮛ" "Ꮜ" "Ꮝ" "Ꮞ" "Ꮟ" "Ꮠ" "Ꮡ" "Ꮢ" "Ꮣ" "Ꮤ" "Ꮥ" "Ꮦ" "Ꮧ" "Ꮨ" "Ꮩ" "Ꮪ" "Ꮫ" "Ꮬ" "Ꮭ" "Ꮮ" "Ꮯ" "Ꮰ" "Ꮱ" "Ꮲ" "Ꮳ" "Ꮴ" "Ꮵ" "Ꮶ" "Ꮷ" "Ꮸ" "Ꮹ" "Ꮺ" "Ꮻ" "Ꮼ" "Ꮽ" "Ꮾ" "Ꮿ" nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil t t t t t t] nil nil nil nil nil nil nil nil] nil nil #^^[2 53248 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil #^^[3 55168 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t] t t t t t t t t t t t t t t t t] t #^^[2 61440 t t t t t t t t t t t t t t t t t t #^^[3 63744 "豈" "更" "車" "賈" "滑" "串" "句" "龜" "龜" "契" "金" "喇" "奈" "懶" "癩" "羅" "蘿" "螺" "裸" "邏" "樂" "洛" "烙" "珞" "落" "酪" "駱" "亂" "卵" "欄" "爛" "蘭" "鸞" "嵐" "濫" "藍" "襤" "拉" "臘" "蠟" "廊" "朗" "浪" "狼" "郎" "來" "冷" "勞" "擄" "櫓" "爐" "盧" "老" "蘆" "虜" "路" "露" "魯" "鷺" "碌" "祿" "綠" "菉" "錄" "鹿" "論" "壟" "弄" "籠" "聾" "牢" "磊" "賂" "雷" "壘" "屢" "樓" "淚" "漏" "累" "縷" "陋" "勒" "肋" "凜" "凌" "稜" "綾" "菱" "陵" "讀" "拏" "樂" "諾" "丹" "寧" "怒" "率" "異" "北" "磻" "便" "復" "不" "泌" "數" "索" "參" "塞" "省" "葉" "說" "殺" "辰" "沈" "拾" "若" "掠" "略" "亮" "兩" "凉" "梁" "糧" "良" "諒" "量" "勵"] #^^[3 63872 "呂" "女" "廬" "旅" "濾" "礪" "閭" "驪" "麗" "黎" "力" "曆" "歷" "轢" "年" "憐" "戀" "撚" "漣" "煉" "璉" "秊" "練" "聯" "輦" "蓮" "連" "鍊" "列" "劣" "咽" "烈" "裂" "說" "廉" "念" "捻" "殮" "簾" "獵" "令" "囹" "寧" "嶺" "怜" "玲" "瑩" "羚" "聆" "鈴" "零" "靈" "領" "例" "禮" "醴" "隸" "惡" "了" "僚" "寮" "尿" "料" "樂" "燎" "療" "蓼" "遼" "龍" "暈" "阮" "劉" "杻" "柳" "流" "溜" "琉" "留" "硫" "紐" "類" "六" "戮" "陸" "倫" "崙" "淪" "輪" "律" "慄" "栗" "率" "隆" "利" "吏" "履" "易" "李" "梨" "泥" "理" "痢" "罹" "裏" "裡" "里" "離" "匿" "溺" "吝" "燐" "璘" "藺" "隣" "鱗" "麟" "林" "淋" "臨" "立" "笠" "粒" "狀" "炙" "識" "什" "茶" "刺"] #^^[3 64000 "切" "度" "拓" "糖" "宅" "洞" "暴" "輻" "行" "降" "見" "廓" "兀" "嗀" nil nil "塚" nil "晴" nil nil "凞" "猪" "益" "礼" "神" "祥" "福" "靖" "精" "羽" nil "蘒" nil "諸" nil nil "逸" "都" nil nil nil "飯" "飼" "館" "鶴" "郞" "隷" "侮" "僧" "免" "勉" "勤" "卑" "喝" "嘆" "器" "塀" "墨" "層" "屮" "悔" "慨" "憎" "懲" "敏" "既" "暑" "梅" "海" "渚" "漢" "煮" "爫" "琢" "碑" "社" "祉" "祈" "祐" "祖" "祝" "禍" "禎" "穀" "突" "節" "練" "縉" "繁" "署" "者" "臭" "艹" "艹" "著" "褐" "視" "謁" "謹" "賓" "贈" "辶" "逸" "難" "響" "頻" "恵" "𤋮" "舘" t t "並" "况" "全" "侀" "充" "冀" "勇" "勺" "喝" "啕" "喙" "嗢" "塚" "墳" "奄" "奔"] #^^[3 64128 "婢" "嬨" "廒" "廙" "彩" "徭" "惘" "慎" "愈" "憎" "慠" "懲" "戴" "揄" "搜" "摒" "敖" "晴" "朗" "望" "杖" "歹" "殺" "流" "滛" "滋" "漢" "瀞" "煮" "瞧" "爵" "犯" "猪" "瑱" "甆" "画" "瘝" "瘟" "益" "盛" "直" "睊" "着" "磌" "窱" "節" "类" "絛" "練" "缾" "者" "荒" "華" "蝹" "襁" "覆" "視" "調" "諸" "請" "謁" "諾" "諭" "謹" "變" "贈" "輸" "遲" "醙" "鉶" "陼" "難" "靖" "韛" "響" "頋" "頻" "鬒" "龜" "𢡊" "𢡄" "𣏕" "㮝" "䀘" "䀹" "𥉉" "𥳐" "𧻓" "齃" "龎" t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] #^^[3 64256 "ff" "fi" "fl" "ffi" "ffl" "st" "st" t t t t t t t t t t t t "մն" "մե" "մի" "վն" "մխ" t t t t t "יִ" nil "ײַ" "ע" "א" "ד" "ה" "כ" "ל" "ם" "ר" "ת" t "שׁ" "שׂ" "שּׁ" "שּׂ" "אַ" "אָ" "אּ" "בּ" "גּ" "דּ" "הּ" "וּ" "זּ" t "טּ" "יּ" "ךּ" "כּ" "לּ" t "מּ" t "נּ" "סּ" t "ףּ" "פּ" t "צּ" "קּ" "רּ" "שּ" "תּ" "וֹ" "בֿ" "כֿ" "פֿ" "אל" "ٱ" "ٱ" "ٻ" "ٻ" "ٻ" "ٻ" "پ" "پ" "پ" "پ" "ڀ" "ڀ" "ڀ" "ڀ" "ٺ" "ٺ" "ٺ" "ٺ" "ٿ" "ٿ" "ٿ" "ٿ" "ٹ" "ٹ" "ٹ" "ٹ" "ڤ" "ڤ" "ڤ" "ڤ" "ڦ" "ڦ" "ڦ" "ڦ" "ڄ" "ڄ" "ڄ" "ڄ" "ڃ" "ڃ" "ڃ" "ڃ" "چ" "چ" "چ" "چ" "ڇ" "ڇ"] #^^[3 64384 "ڇ" "ڇ" "ڍ" "ڍ" "ڌ" "ڌ" "ڎ" "ڎ" "ڈ" "ڈ" "ژ" "ژ" "ڑ" "ڑ" "ک" "ک" "ک" "ک" "گ" "گ" "گ" "گ" "ڳ" "ڳ" "ڳ" "ڳ" "ڱ" "ڱ" "ڱ" "ڱ" "ں" "ں" "ڻ" "ڻ" "ڻ" "ڻ" "ۀ" "ۀ" "ہ" "ہ" "ہ" "ہ" "ھ" "ھ" "ھ" "ھ" "ے" "ے" "ۓ" "ۓ" nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t "ڭ" "ڭ" "ڭ" "ڭ" "ۇ" "ۇ" "ۆ" "ۆ" "ۈ" "ۈ" "ۇٴ" "ۋ" "ۋ" "ۅ" "ۅ" "ۉ" "ۉ" "ې" "ې" "ې" "ې" "ى" "ى" "ئا" "ئا" "ئە" "ئە" "ئو" "ئو" "ئۇ" "ئۇ" "ئۆ" "ئۆ" "ئۈ" "ئۈ" "ئې" "ئې" "ئې" "ئى" "ئى" "ئى" "ی" "ی" "ی" "ی"] #^^[3 64512 "ئج" "ئح" "ئم" "ئى" "ئي" "بج" "بح" "بخ" "بم" "بى" "بي" "تج" "تح" "تخ" "تم" "تى" "تي" "ثج" "ثم" "ثى" "ثي" "جح" "جم" "حج" "حم" "خج" "خح" "خم" "سج" "سح" "سخ" "سم" "صح" "صم" "ضج" "ضح" "ضخ" "ضم" "طح" "طم" "ظم" "عج" "عم" "غج" "غم" "فج" "فح" "فخ" "فم" "فى" "في" "قح" "قم" "قى" "قي" "كا" "كج" "كح" "كخ" "كل" "كم" "كى" "كي" "لج" "لح" "لخ" "لم" "لى" "لي" "مج" "مح" "مخ" "مم" "مى" "مي" "نج" "نح" "نخ" "نم" "نى" "ني" "هج" "هم" "هى" "هي" "يج" "يح" "يخ" "يم" "يى" "يي" "ذٰ" "رٰ" "ىٰ" t t t t t t "ئر" "ئز" "ئم" "ئن" "ئى" "ئي" "بر" "بز" "بم" "بن" "بى" "بي" "تر" "تز" "تم" "تن" "تى" "تي" "ثر" "ثز" "ثم" "ثن" "ثى" "ثي" "فى" "في" "قى" "قي"] #^^[3 64640 "كا" "كل" "كم" "كى" "كي" "لم" "لى" "لي" "ما" "مم" "نر" "نز" "نم" "نن" "نى" "ني" "ىٰ" "ير" "يز" "يم" "ين" "يى" "يي" "ئج" "ئح" "ئخ" "ئم" "ئه" "بج" "بح" "بخ" "بم" "به" "تج" "تح" "تخ" "تم" "ته" "ثم" "جح" "جم" "حج" "حم" "خج" "خم" "سج" "سح" "سخ" "سم" "صح" "صخ" "صم" "ضج" "ضح" "ضخ" "ضم" "طح" "ظم" "عج" "عم" "غج" "غم" "فج" "فح" "فخ" "فم" "قح" "قم" "كج" "كح" "كخ" "كل" "كم" "لج" "لح" "لخ" "لم" "له" "مج" "مح" "مخ" "مم" "نج" "نح" "نخ" "نم" "نه" "هج" "هم" "هٰ" "يج" "يح" "يخ" "يم" "يه" "ئم" "ئه" "بم" "به" "تم" "ته" "ثم" "ثه" "سم" "سه" "شم" "شه" "كل" "كم" "لم" "نم" "نه" "يم" "يه" "ـَّ" "ـُّ" "ـِّ" "طى" "طي" "عى" "عي" "غى" "غي" "سى" "سي" "شى" "شي" "حى"] #^^[3 64768 "حي" "جى" "جي" "خى" "خي" "صى" "صي" "ضى" "ضي" "شج" "شح" "شخ" "شم" "شر" "سر" "صر" "ضر" "طى" "طي" "عى" "عي" "غى" "غي" "سى" "سي" "شى" "شي" "حى" "حي" "جى" "جي" "خى" "خي" "صى" "صي" "ضى" "ضي" "شج" "شح" "شخ" "شم" "شر" "سر" "صر" "ضر" "شج" "شح" "شخ" "شم" "سه" "شه" "طم" "سج" "سح" "سخ" "شج" "شح" "شخ" "طم" "ظم" "اً" "اً" nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil "تجم" "تحج" "تحج" "تحم" "تخم" "تمج" "تمح" "تمخ" "جمح" "جمح" "حمي" "حمى" "سحج" "سجح" "سجى" "سمح" "سمح" "سمج" "سمم" "سمم" "صحح" "صحح" "صمم" "شحم" "شحم" "شجي" "شمخ" "شمخ" "شمم" "شمم" "ضحى" "ضخم" "ضخم" "طمح" "طمح" "طمم" "طمي" "عجم" "عمم" "عمم" "عمى" "غمم" "غمي" "غمى" "فخم" "فخم" "قمح" "قمم"] #^^[3 64896 "لحم" "لحي" "لحى" "لجج" "لجج" "لخم" "لخم" "لمح" "لمح" "محج" "محم" "محي" "مجح" "مجم" "مخج" "مخم" t t "مجخ" "همج" "همم" "نحم" "نحى" "نجم" "نجم" "نجى" "نمي" "نمى" "يمم" "يمم" "بخي" "تجي" "تجى" "تخي" "تخى" "تمي" "تمى" "جمي" "جحى" "جمى" "سخى" "صحي" "شحي" "ضحي" "لجي" "لمي" "يحي" "يجي" "يمي" "ممي" "قمي" "نحي" "قمح" "لحم" "عمي" "كمي" "نجح" "مخي" "لجم" "كمم" "لجم" "نجح" "جحي" "حجي" "مجي" "فمي" "بحي" "كمم" "عجم" "صمم" "سخي" "نجي" t t t t t t t nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t "صلے" "قلے" "الله" "اكبر" "محمد" "صلعم" "رسول" "عليه" "وسلم" "صلى" t t "ریال" nil nil nil] #^^[3 65024 ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored t "、" t t t t t "〖" "〗" t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t "—" "–" t t t t t t "〔" "〕" "【" "】" "《" "》" "〈" "〉" "「" "」" "『" "』" nil nil t t t t t t t t t t "、" t t t t t t "—" t t t t "〔" "〕" t t t t "-" t t t t t t t t t t t t t "ـً" t nil t t t "ـَ" t "ـُ" t "ـِ" t "ـّ" t "ـْ"] #^^[3 65152 "ء" "آ" "آ" "أ" "أ" "ؤ" "ؤ" "إ" "إ" "ئ" "ئ" "ئ" "ئ" "ا" "ا" "ب" "ب" "ب" "ب" "ة" "ة" "ت" "ت" "ت" "ت" "ث" "ث" "ث" "ث" "ج" "ج" "ج" "ج" "ح" "ح" "ح" "ح" "خ" "خ" "خ" "خ" "د" "د" "ذ" "ذ" "ر" "ر" "ز" "ز" "س" "س" "س" "س" "ش" "ش" "ش" "ش" "ص" "ص" "ص" "ص" "ض" "ض" "ض" "ض" "ط" "ط" "ط" "ط" "ظ" "ظ" "ظ" "ظ" "ع" "ع" "ع" "ع" "غ" "غ" "غ" "غ" "ف" "ف" "ف" "ف" "ق" "ق" "ق" "ق" "ك" "ك" "ك" "ك" "ل" "ل" "ل" "ل" "م" "م" "م" "م" "ن" "ن" "ن" "ن" "ه" "ه" "ه" "ه" "و" "و" "ى" "ى" "ي" "ي" "ي" "ي" "لآ" "لآ" "لأ" "لأ" "لإ" "لإ" "لا" "لا" t t ignored] #^^[3 65280 t t t t t t t t t t t t t "-" "." t "0" "1" "2" "3" "4" "5" "6" "7" "8" "9" t t t t t t t "a" "b" "c" "d" "e" "f" "g" "h" "i" "j" "k" "l" "m" "n" "o" "p" "q" "r" "s" "t" "u" "v" "w" "x" "y" "z" t t t t t t "a" "b" "c" "d" "e" "f" "g" "h" "i" "j" "k" "l" "m" "n" "o" "p" "q" "r" "s" "t" "u" "v" "w" "x" "y" "z" t t t t "⦅" "⦆" "." "「" "」" "、" "・" "ヲ" "ァ" "ィ" "ゥ" "ェ" "ォ" "ャ" "ュ" "ョ" "ッ" "ー" "ア" "イ" "ウ" "エ" "オ" "カ" "キ" "ク" "ケ" "コ" "サ" "シ" "ス" "セ" "ソ"] #^^[3 65408 "タ" "チ" "ツ" "テ" "ト" "ナ" "ニ" "ヌ" "ネ" "ノ" "ハ" "ヒ" "フ" "ヘ" "ホ" "マ" "ミ" "ム" "メ" "モ" "ヤ" "ユ" "ヨ" "ラ" "リ" "ル" "レ" "ロ" "ワ" "ン" "゙" "゚" t "ᄀ" "ᄁ" "ᆪ" "ᄂ" "ᆬ" "ᆭ" "ᄃ" "ᄄ" "ᄅ" "ᆰ" "ᆱ" "ᆲ" "ᆳ" "ᆴ" "ᆵ" "ᄚ" "ᄆ" "ᄇ" "ᄈ" "ᄡ" "ᄉ" "ᄊ" "ᄋ" "ᄌ" "ᄍ" "ᄎ" "ᄏ" "ᄐ" "ᄑ" "ᄒ" t t t "ᅡ" "ᅢ" "ᅣ" "ᅤ" "ᅥ" "ᅦ" t t "ᅧ" "ᅨ" "ᅩ" "ᅪ" "ᅫ" "ᅬ" t t "ᅭ" "ᅮ" "ᅯ" "ᅰ" "ᅱ" "ᅲ" t t "ᅳ" "ᅴ" "ᅵ" t t t "¢" "£" "¬" t "¦" "¥" "₩" t "│" "←" "↑" "→" "↓" "■" "○" t t t t t t t t t t t t t t t t t]]] #^^[1 65536 #^^[2 65536 #^^[3 65536 nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] #^^[3 65664 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t] #^^[3 65792 nil nil nil t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 65920 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil t t t nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t] t #^^[3 66176 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t] #^^[3 66304 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t] #^^[3 66432 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] #^^[3 66560 "𐐨" "𐐩" "𐐪" "𐐫" "𐐬" "𐐭" "𐐮" "𐐯" "𐐰" "𐐱" "𐐲" "𐐳" "𐐴" "𐐵" "𐐶" "𐐷" "𐐸" "𐐹" "𐐺" "𐐻" "𐐼" "𐐽" "𐐾" "𐐿" "𐑀" "𐑁" "𐑂" "𐑃" "𐑄" "𐑅" "𐑆" "𐑇" "𐑈" "𐑉" "𐑊" "𐑋" "𐑌" "𐑍" "𐑎" "𐑏" nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 66688 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil t t t t t t "𐓘" "𐓙" "𐓚" "𐓛" "𐓜" "𐓝" "𐓞" "𐓟" "𐓠" "𐓡" "𐓢" "𐓣" "𐓤" "𐓥" "𐓦" "𐓧" "𐓨" "𐓩" "𐓪" "𐓫" "𐓬" "𐓭" "𐓮" "𐓯" "𐓰" "𐓱" "𐓲" "𐓳" "𐓴" "𐓵" "𐓶" "𐓷" "𐓸" "𐓹" "𐓺" "𐓻" t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t] #^^[3 66816 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t nil "𐖗" "𐖘" "𐖙" "𐖚" "𐖛" "𐖜" "𐖝" "𐖞" "𐖟" "𐖠" "𐖡" t "𐖣" "𐖤" "𐖥" "𐖦"] #^^[3 66944 "𐖧" "𐖨" "𐖩" "𐖪" "𐖫" "𐖬" "𐖭" "𐖮" "𐖯" "𐖰" "𐖱" t "𐖳" "𐖴" "𐖵" "𐖶" "𐖷" "𐖸" "𐖹" t "𐖻" "𐖼" t nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil t nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] nil nil #^^[3 67328 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t] #^^[3 67456 nil "ː" "ˑ" "æ" "ʙ" "ɓ" t "ʣ" "ꭦ" "ʥ" "ʤ" "ɖ" "ɗ" "ᶑ" "ɘ" "ɞ" "ʩ" "ɤ" "ɢ" "ɠ" "ʛ" "ħ" "ʜ" "ɧ" "ʄ" "ʪ" "ʫ" "ɬ" "𝼄" "ꞎ" "ɮ" "𝼅" "ʎ" "𝼆" "ø" "ɶ" "ɷ" "q" "ɺ" "𝼈" "ɽ" "ɾ" "ʀ" "ʨ" "ʦ" "ꭧ" "ʧ" "ʈ" "ⱱ" t "ʏ" "ʡ" "ʢ" "ʘ" "ǀ" "ǁ" "ǂ" "𝼊" "𝼞" t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] #^^[3 67584 nil nil nil nil nil nil t t nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil t t t nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 67712 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil t t t t t nil nil nil nil nil] #^^[3 67840 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] #^^[3 67968 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 68096 nil nil nil nil t nil nil t t t t t nil nil nil nil nil nil nil nil t nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil nil t t t t nil nil nil nil nil nil nil nil nil nil t t t t t t t nil nil nil nil nil nil nil nil nil t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 68224 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t] #^^[3 68352 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t nil nil nil nil nil nil nil nil] #^^[3 68480 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t nil nil nil nil t t t t t t t t t t t t nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] #^^[3 68608 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] #^^[3 68736 "𐳀" "𐳁" "𐳂" "𐳃" "𐳄" "𐳅" "𐳆" "𐳇" "𐳈" "𐳉" "𐳊" "𐳋" "𐳌" "𐳍" "𐳎" "𐳏" "𐳐" "𐳑" "𐳒" "𐳓" "𐳔" "𐳕" "𐳖" "𐳗" "𐳘" "𐳙" "𐳚" "𐳛" "𐳜" "𐳝" "𐳞" "𐳟" "𐳠" "𐳡" "𐳢" "𐳣" "𐳤" "𐳥" "𐳦" "𐳧" "𐳨" "𐳩" "𐳪" "𐳫" "𐳬" "𐳭" "𐳮" "𐳯" "𐳰" "𐳱" "𐳲" t t t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t nil nil nil nil nil nil] #^^[3 68864 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] t #^^[3 69120 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t] #^^[3 69248 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil t t nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t nil nil nil] #^^[3 69376 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 69504 nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t]] #^^[2 69632 #^^[3 69632 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t nil] #^^[3 69760 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil t t t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t nil nil nil nil nil nil nil nil nil nil t t t t t t] #^^[3 69888 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t] #^^[3 70016 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t] #^^[3 70144 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] #^^[3 70272 nil nil nil nil nil nil nil t nil t nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t nil nil nil nil nil nil nil nil nil nil t t t t t t] #^^[3 70400 nil nil nil nil t nil nil nil nil nil nil nil nil t t nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil t nil nil t nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil t t nil nil t t nil nil nil t t nil t t t t t t nil t t t t t nil nil nil nil nil nil nil t t nil nil nil nil nil nil nil t t t nil nil nil nil nil t t t t t t t t t t t] t #^^[3 70656 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] #^^[3 70784 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] t #^^[3 71040 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] #^^[3 71168 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t] #^^[3 71296 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] #^^[3 71424 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] t #^^[3 71680 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] #^^[3 71808 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t "𑣀" "𑣁" "𑣂" "𑣃" "𑣄" "𑣅" "𑣆" "𑣇" "𑣈" "𑣉" "𑣊" "𑣋" "𑣌" "𑣍" "𑣎" "𑣏" "𑣐" "𑣑" "𑣒" "𑣓" "𑣔" "𑣕" "𑣖" "𑣗" "𑣘" "𑣙" "𑣚" "𑣛" "𑣜" "𑣝" "𑣞" "𑣟" nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t nil] #^^[3 71936 nil nil nil nil nil nil nil t t nil t t nil nil nil nil nil nil nil nil t nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] #^^[3 72064 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t nil nil nil nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t] #^^[3 72192 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 72320 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t] #^^[3 72448 nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] t #^^[3 72704 nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 72832 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] #^^[3 72960 nil nil nil nil nil nil nil t nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t nil t nil nil t nil nil nil nil nil nil nil nil nil t t t t t t t t nil nil nil nil nil nil nil nil nil nil t t t t t t nil nil nil nil nil nil t nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 73088 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil t nil nil nil nil nil nil t t t t t t t nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] t #^^[3 73344 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t] #^^[3 73472 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] #^^[3 73600 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t nil t t t t t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t nil]] #^^[2 73728 nil nil nil nil nil nil nil #^^[3 74624 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] #^^[3 74752 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil t t t t t t t t t t t] nil #^^[3 75008 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] t t t t t t t t t t t t t t t t t t t t #^^[3 77696 t t t t t t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t]] #^^[2 77824 nil nil nil nil nil nil nil nil #^^[3 78848 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] t t t t t t t t t t t t t t t t t t t t t t t] #^^[2 81920 t t t t t t t t nil nil nil nil #^^[3 83456 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] t t t t t t t t t t t t t t t t t t t] t #^^[2 90112 t t t t t t t t t t t t t t t t nil nil nil nil #^^[3 92672 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 92800 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil nil nil t t t t t t t t t t] #^^[3 92928 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t nil nil nil] #^^[3 93056 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] t t t t #^^[3 93696 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t "𖹠" "𖹡" "𖹢" "𖹣" "𖹤" "𖹥" "𖹦" "𖹧" "𖹨" "𖹩" "𖹪" "𖹫" "𖹬" "𖹭" "𖹮" "𖹯" "𖹰" "𖹱" "𖹲" "𖹳" "𖹴" "𖹵" "𖹶" "𖹷" "𖹸" "𖹹" "𖹺" "𖹻" "𖹼" "𖹽" "𖹾" "𖹿" nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 93824 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] #^^[3 93952 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 94080 nil nil nil nil nil nil nil nil t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t nil nil nil nil nil t t t t t t t t t t t nil nil t t t t t t t t t t t t t t]] nil #^^[2 98304 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil #^^[3 100224 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t] nil nil nil nil nil nil nil nil nil #^^[3 101504 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] #^^[3 101632 nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] t t t t t] t #^^[2 106496 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t #^^[3 110464 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t nil nil nil nil t nil nil nil nil nil nil nil t nil nil t]] #^^[2 110592 nil nil #^^[3 110848 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t nil nil nil t t nil t t t t t t t t t t t t t t nil nil nil nil t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] nil nil #^^[3 111232 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t] t t t t t t t t t t t t t t t t t t #^^[3 113664 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil t t t] #^^[3 113792 nil nil nil nil nil nil nil nil nil t t t t t t t nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil ignored ignored ignored ignored t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] t t t t t t] #^^[2 114688 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t #^^[3 118528 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 118656 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t]] #^^[2 118784 nil #^^[3 118912 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t] #^^[3 119040 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil "𝅗𝅥" "𝅘𝅥" "𝅘𝅥𝅮" "𝅘𝅥𝅯" "𝅘𝅥𝅰" "𝅘𝅥𝅱" "𝅘𝅥𝅲" nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t nil nil nil nil nil] #^^[3 119168 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil "𝆹𝅥" "𝆺𝅥" "𝆹𝅥𝅮" "𝆺𝅥𝅮" "𝆹𝅥𝅯" "𝆺𝅥𝅯" nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t] #^^[3 119296 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] #^^[3 119424 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t] #^^[3 119552 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t] t #^^[3 119808 "a" "b" "c" "d" "e" "f" "g" "h" "i" "j" "k" "l" "m" "n" "o" "p" "q" "r" "s" "t" "u" "v" "w" "x" "y" "z" "a" "b" "c" "d" "e" "f" "g" "h" "i" "j" "k" "l" "m" "n" "o" "p" "q" "r" "s" "t" "u" "v" "w" "x" "y" "z" "a" "b" "c" "d" "e" "f" "g" "h" "i" "j" "k" "l" "m" "n" "o" "p" "q" "r" "s" "t" "u" "v" "w" "x" "y" "z" "a" "b" "c" "d" "e" "f" "g" t "i" "j" "k" "l" "m" "n" "o" "p" "q" "r" "s" "t" "u" "v" "w" "x" "y" "z" "a" "b" "c" "d" "e" "f" "g" "h" "i" "j" "k" "l" "m" "n" "o" "p" "q" "r" "s" "t" "u" "v" "w" "x"] #^^[3 119936 "y" "z" "a" "b" "c" "d" "e" "f" "g" "h" "i" "j" "k" "l" "m" "n" "o" "p" "q" "r" "s" "t" "u" "v" "w" "x" "y" "z" "a" t "c" "d" t t "g" t t "j" "k" t t "n" "o" "p" "q" t "s" "t" "u" "v" "w" "x" "y" "z" "a" "b" "c" "d" t "f" t "h" "i" "j" "k" "l" "m" "n" t "p" "q" "r" "s" "t" "u" "v" "w" "x" "y" "z" "a" "b" "c" "d" "e" "f" "g" "h" "i" "j" "k" "l" "m" "n" "o" "p" "q" "r" "s" "t" "u" "v" "w" "x" "y" "z" "a" "b" "c" "d" "e" "f" "g" "h" "i" "j" "k" "l" "m" "n" "o" "p" "q" "r" "s" "t" "u" "v"] #^^[3 120064 "w" "x" "y" "z" "a" "b" t "d" "e" "f" "g" t t "j" "k" "l" "m" "n" "o" "p" "q" t "s" "t" "u" "v" "w" "x" "y" t "a" "b" "c" "d" "e" "f" "g" "h" "i" "j" "k" "l" "m" "n" "o" "p" "q" "r" "s" "t" "u" "v" "w" "x" "y" "z" "a" "b" t "d" "e" "f" "g" t "i" "j" "k" "l" "m" t "o" t t t "s" "t" "u" "v" "w" "x" "y" t "a" "b" "c" "d" "e" "f" "g" "h" "i" "j" "k" "l" "m" "n" "o" "p" "q" "r" "s" "t" "u" "v" "w" "x" "y" "z" "a" "b" "c" "d" "e" "f" "g" "h" "i" "j" "k" "l" "m" "n" "o" "p" "q" "r" "s" "t"] #^^[3 120192 "u" "v" "w" "x" "y" "z" "a" "b" "c" "d" "e" "f" "g" "h" "i" "j" "k" "l" "m" "n" "o" "p" "q" "r" "s" "t" "u" "v" "w" "x" "y" "z" "a" "b" "c" "d" "e" "f" "g" "h" "i" "j" "k" "l" "m" "n" "o" "p" "q" "r" "s" "t" "u" "v" "w" "x" "y" "z" "a" "b" "c" "d" "e" "f" "g" "h" "i" "j" "k" "l" "m" "n" "o" "p" "q" "r" "s" "t" "u" "v" "w" "x" "y" "z" "a" "b" "c" "d" "e" "f" "g" "h" "i" "j" "k" "l" "m" "n" "o" "p" "q" "r" "s" "t" "u" "v" "w" "x" "y" "z" "a" "b" "c" "d" "e" "f" "g" "h" "i" "j" "k" "l" "m" "n" "o" "p" "q" "r"] #^^[3 120320 "s" "t" "u" "v" "w" "x" "y" "z" "a" "b" "c" "d" "e" "f" "g" "h" "i" "j" "k" "l" "m" "n" "o" "p" "q" "r" "s" "t" "u" "v" "w" "x" "y" "z" "a" "b" "c" "d" "e" "f" "g" "h" "i" "j" "k" "l" "m" "n" "o" "p" "q" "r" "s" "t" "u" "v" "w" "x" "y" "z" "a" "b" "c" "d" "e" "f" "g" "h" "i" "j" "k" "l" "m" "n" "o" "p" "q" "r" "s" "t" "u" "v" "w" "x" "y" "z" "a" "b" "c" "d" "e" "f" "g" "h" "i" "j" "k" "l" "m" "n" "o" "p" "q" "r" "s" "t" "u" "v" "w" "x" "y" "z" "a" "b" "c" "d" "e" "f" "g" "h" "i" "j" "k" "l" "m" "n" "o" "p"] #^^[3 120448 "q" "r" "s" "t" "u" "v" "w" "x" "y" "z" "a" "b" "c" "d" "e" "f" "g" "h" "i" "j" "k" "l" "m" "n" "o" "p" "q" "r" "s" "t" "u" "v" "w" "x" "y" "z" "ı" "ȷ" t t "α" "β" "γ" "δ" "ε" "ζ" "η" "θ" "ι" "κ" "λ" "μ" "ν" "ξ" "ο" "π" "ρ" "θ" "σ" "τ" "υ" "φ" "χ" "ψ" "ω" "∇" "α" "β" "γ" "δ" "ε" "ζ" "η" "θ" "ι" "κ" "λ" "μ" "ν" "ξ" "ο" "π" "ρ" "σ" "σ" "τ" "υ" "φ" "χ" "ψ" "ω" "∂" "ε" "θ" "κ" "φ" "ρ" "π" "α" "β" "γ" "δ" "ε" "ζ" "η" "θ" "ι" "κ" "λ" "μ" "ν" "ξ" "ο" "π" "ρ" "θ" "σ" "τ" "υ" "φ" "χ" "ψ" "ω" "∇" "α" "β" "γ" "δ"] #^^[3 120576 "ε" "ζ" "η" "θ" "ι" "κ" "λ" "μ" "ν" "ξ" "ο" "π" "ρ" "σ" "σ" "τ" "υ" "φ" "χ" "ψ" "ω" "∂" "ε" "θ" "κ" "φ" "ρ" "π" "α" "β" "γ" "δ" "ε" "ζ" "η" "θ" "ι" "κ" "λ" "μ" "ν" "ξ" "ο" "π" "ρ" "θ" "σ" "τ" "υ" "φ" "χ" "ψ" "ω" "∇" "α" "β" "γ" "δ" "ε" "ζ" "η" "θ" "ι" "κ" "λ" "μ" "ν" "ξ" "ο" "π" "ρ" "σ" "σ" "τ" "υ" "φ" "χ" "ψ" "ω" "∂" "ε" "θ" "κ" "φ" "ρ" "π" "α" "β" "γ" "δ" "ε" "ζ" "η" "θ" "ι" "κ" "λ" "μ" "ν" "ξ" "ο" "π" "ρ" "θ" "σ" "τ" "υ" "φ" "χ" "ψ" "ω" "∇" "α" "β" "γ" "δ" "ε" "ζ" "η" "θ" "ι" "κ" "λ" "μ" "ν" "ξ" "ο" "π"] #^^[3 120704 "ρ" "σ" "σ" "τ" "υ" "φ" "χ" "ψ" "ω" "∂" "ε" "θ" "κ" "φ" "ρ" "π" "α" "β" "γ" "δ" "ε" "ζ" "η" "θ" "ι" "κ" "λ" "μ" "ν" "ξ" "ο" "π" "ρ" "θ" "σ" "τ" "υ" "φ" "χ" "ψ" "ω" "∇" "α" "β" "γ" "δ" "ε" "ζ" "η" "θ" "ι" "κ" "λ" "μ" "ν" "ξ" "ο" "π" "ρ" "σ" "σ" "τ" "υ" "φ" "χ" "ψ" "ω" "∂" "ε" "θ" "κ" "φ" "ρ" "π" "ϝ" "ϝ" t t "0" "1" "2" "3" "4" "5" "6" "7" "8" "9" "0" "1" "2" "3" "4" "5" "6" "7" "8" "9" "0" "1" "2" "3" "4" "5" "6" "7" "8" "9" "0" "1" "2" "3" "4" "5" "6" "7" "8" "9" "0" "1" "2" "3" "4" "5" "6" "7" "8" "9"] nil nil nil nil nil #^^[3 121472 nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] t t t t t t t t #^^[3 122624 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] t] #^^[2 122880 #^^[3 122880 nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil nil nil nil t nil nil t nil nil nil nil nil t t t t t "а" "б" "в" "г" "д" "е" "ж" "з" "и" "к" "л" "м" "о" "п" "р" "с" "т" "у" "ф" "х" "ц" "ч" "ш" "ы" "э" "ю" "ꚉ" "ә" "і" "ј" "ө" "ү" "ӏ" "а" "б" "в" "г" "д" "е" "ж" "з" "и" "к" "л" "о" "п" "с" "у" "ф" "х" "ц" "ч" "ш" "ъ" "ы" "ґ" "і" "ѕ" "џ" "ҫ" "ꙑ" "ұ" t t t t t t t t t t t t t t t t t t] #^^[3 123008 t t t t t t t t t t t t t t t nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] #^^[3 123136 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil t t t t nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] t t #^^[3 123520 t t t t t t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t nil] t t t #^^[3 124032 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t] t t t t t #^^[3 124800 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t nil nil nil nil nil nil nil t nil nil nil nil t nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t] nil #^^[3 125056 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] #^^[3 125184 "𞤢" "𞤣" "𞤤" "𞤥" "𞤦" "𞤧" "𞤨" "𞤩" "𞤪" "𞤫" "𞤬" "𞤭" "𞤮" "𞤯" "𞤰" "𞤱" "𞤲" "𞤳" "𞤴" "𞤵" "𞤶" "𞤷" "𞤸" "𞤹" "𞤺" "𞤻" "𞤼" "𞤽" "𞤾" "𞤿" "𞥀" "𞥁" "𞥂" "𞥃" nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t nil nil nil nil nil nil nil nil nil nil t t t t nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] t t t t t #^^[3 125952 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 126080 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] #^^[3 126208 t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] t #^^[3 126464 "ا" "ب" "ج" "د" t "و" "ز" "ح" "ط" "ي" "ك" "ل" "م" "ن" "س" "ع" "ف" "ص" "ق" "ر" "ش" "ت" "ث" "خ" "ذ" "ض" "ظ" "غ" "ٮ" "ں" "ڡ" "ٯ" t "ب" "ج" t "ه" t t "ح" t "ي" "ك" "ل" "م" "ن" "س" "ع" "ف" "ص" "ق" t "ش" "ت" "ث" "خ" t "ض" t "غ" t t t t t t "ج" t t t t "ح" t "ي" t "ل" t "ن" "س" "ع" t "ص" "ق" t "ش" t t "خ" t "ض" t "غ" t "ں" t "ٯ" t "ب" "ج" t "ه" t t "ح" "ط" "ي" "ك" t "م" "ن" "س" "ع" "ف" "ص" "ق" t "ش" "ت" "ث" "خ" t "ض" "ظ" "غ" "ٮ" t "ڡ" t] #^^[3 126592 "ا" "ب" "ج" "د" "ه" "و" "ز" "ح" "ط" "ي" t "ل" "م" "ن" "س" "ع" "ف" "ص" "ق" "ر" "ش" "ت" "ث" "خ" "ذ" "ض" "ظ" "غ" t t t t t "ب" "ج" "د" t "و" "ز" "ح" "ط" "ي" t "ل" "م" "ن" "س" "ع" "ف" "ص" "ق" "ر" "ش" "ت" "ث" "خ" "ذ" "ض" "ظ" "غ" t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t nil nil t t t t t t t t t t t t t t] t t] #^^[2 126976 #^^[3 126976 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 127104 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t] #^^[3 127232 t t t t t t t t t t t nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t "〔s〕" "c" "r" "cd" "wz" nil "a" "b" "c" "d" "e" "f" "g" "h" "i" "j" "k" "l" "m" "n" "o" "p" "q" "r" "s" "t" "u" "v" "w" "x" "y" "z" "hv" "mv" "sd" "ss" "ppv" "wc" nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil "mc" "md" "mr" nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 127360 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil "dj" nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 127488 "ほか" "ココ" "サ" t t t t t t t t t t t t t "手" "字" "双" "デ" "二" "多" "解" "天" "交" "映" "無" "料" "前" "後" "再" "新" "初" "終" "生" "販" "声" "吹" "演" "投" "捕" "一" "三" "遊" "左" "中" "右" "指" "走" "打" "禁" "空" "合" "満" "有" "月" "申" "割" "営" "配" t t t t "〔本〕" "〔三〕" "〔二〕" "〔安〕" "〔点〕" "〔打〕" "〔盗〕" "〔勝〕" "〔敗〕" t t t t t t t "得" "可" t t t t t t t t t t t t t t nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t] t nil nil nil nil nil nil nil #^^[3 128640 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t nil nil nil nil nil nil nil nil nil nil nil nil nil t t t] #^^[3 128768 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t nil nil nil nil nil] #^^[3 128896 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil t t t t nil t t t t t t t t t t t t t t t] #^^[3 129024 nil nil nil nil nil nil nil nil nil nil nil nil t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t nil nil nil nil nil nil nil nil nil nil t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[3 129152 nil nil nil nil nil nil nil nil t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] nil nil #^^[3 129536 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil t t t] #^^[3 129664 nil nil nil nil nil nil nil nil nil t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t nil nil nil nil nil nil nil nil nil t t t t t t t nil nil nil nil nil nil nil nil nil t t t t t t t] nil #^^[3 129920 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t "0" "1" "2" "3" "4" "5" "6" "7" "8" "9" t t t t t t] t t t t t t t #^^[3 130944 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t]]] #^^[1 131072 nil nil nil nil nil nil nil nil nil nil #^^[2 172032 nil nil nil nil nil nil nil nil nil nil nil nil nil #^^[3 173696 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[2 176128 nil nil nil nil nil nil nil nil nil nil nil nil nil nil #^^[3 177920 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] nil #^^[3 178176 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[2 180224 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil #^^[3 183936 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] nil nil] nil #^^[2 188416 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil #^^[3 191360 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] nil nil nil nil #^^[3 192000 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] t t t] #^^[2 192512 t t t t t t t t t t t t t t t t #^^[3 194560 "丽" "丸" "乁" "𠄢" "你" "侮" "侻" "倂" "偺" "備" "僧" "像" "㒞" "𠘺" "免" "兔" "兤" "具" "𠔜" "㒹" "內" "再" "𠕋" "冗" "冤" "仌" "冬" "况" "𩇟" "凵" "刃" "㓟" "刻" "剆" "割" "剷" "㔕" "勇" "勉" "勤" "勺" "包" "匆" "北" "卉" "卑" "博" "即" "卽" "卿" "卿" "卿" "𠨬" "灰" "及" "叟" "𠭣" "叫" "叱" "吆" "咞" "吸" "呈" "周" "咢" "哶" "唐" "啓" "啣" "善" "善" "喙" "喫" "喳" "嗂" "圖" "嘆" "圗" "噑" "噴" "切" "壮" "城" "埴" "堍" "型" "堲" "報" "墬" "𡓤" "売" "壷" "夆" "多" "夢" "奢" "𡚨" "𡛪" "姬" "娛" "娧" "姘" "婦" "㛮" t "嬈" "嬾" "嬾" "𡧈" "寃" "寘" "寧" "寳" "𡬘" "寿" "将" t "尢" "㞁" "屠" "屮" "峀" "岍" "𡷤" "嵃" "𡷦" "嵮" "嵫"] #^^[3 194688 "嵼" "巡" "巢" "㠯" "巽" "帨" "帽" "幩" "㡢" "𢆃" "㡼" "庰" "庳" "庶" "廊" "𪎒" "廾" "𢌱" "𢌱" "舁" "弢" "弢" "㣇" "𣊸" "𦇚" "形" "彫" "㣣" "徚" "忍" "志" "忹" "悁" "㤺" "㤜" "悔" "𢛔" "惇" "慈" "慌" "慎" "慌" "慺" "憎" "憲" "憤" "憯" "懞" "懲" "懶" "成" "戛" "扝" "抱" "拔" "捐" "𢬌" "挽" "拼" "捨" "掃" "揤" "𢯱" "搢" "揅" "掩" "㨮" "摩" "摾" "撝" "摷" "㩬" "敏" "敬" "𣀊" "旣" "書" "晉" "㬙" "暑" "㬈" "㫤" "冒" "冕" "最" "暜" "肭" "䏙" "朗" "望" "朡" "杞" "杓" "𣏃" "㭉" "柺" "枅" "桒" "梅" "𣑭" "梎" "栟" "椔" "㮝" "楂" "榣" "槪" "檨" "𣚣" "櫛" "㰘" "次" "𣢧" "歔" "㱎" "歲" "殟" "殺" "殻" "𣪍" "𡴋" "𣫺" "汎" "𣲼" "沿" "泍" "汧" "洖"] #^^[3 194816 "派" "海" "流" "浩" "浸" "涅" "𣴞" "洴" "港" "湮" "㴳" "滋" "滇" "𣻑" "淹" "潮" "𣽞" "𣾎" "濆" "瀹" "瀞" "瀛" "㶖" "灊" "災" "灷" "炭" "𠔥" "煅" "𤉣" "熜" t "爨" "爵" "牐" "𤘈" "犀" "犕" "𤜵" "𤠔" "獺" "王" "㺬" "玥" "㺸" "㺸" "瑇" "瑜" "瑱" "璅" "瓊" "㼛" "甤" "𤰶" "甾" "𤲒" "異" "𢆟" "瘐" "𤾡" "𤾸" "𥁄" "㿼" "䀈" "直" "𥃳" "𥃲" "𥄙" "𥄳" "眞" "真" "真" "睊" "䀹" "瞋" "䁆" "䂖" "𥐝" "硎" "碌" "磌" "䃣" "𥘦" "祖" "𥚚" "𥛅" "福" "秫" "䄯" "穀" "穊" "穏" "𥥼" "𥪧" "𥪧" t "䈂" "𥮫" "篆" "築" "䈧" "𥲀" "糒" "䊠" "糨" "糣" "紀" "𥾆" "絣" "䌁" "緇" "縂" "繅" "䌴" "𦈨" "𦉇" "䍙" "𦋙" "罺" "𦌾" "羕" "翺" "者" "𦓚" "𦔣" "聠" "𦖨" "聰"] #^^[3 194944 "𣍟" "䏕" "育" "脃" "䐋" "脾" "媵" "𦞧" "𦞵" "𣎓" "𣎜" "舁" "舄" "辞" "䑫" "芑" "芋" "芝" "劳" "花" "芳" "芽" "苦" "𦬼" "若" "茝" "荣" "莭" "茣" "莽" "菧" "著" "荓" "菊" "菌" "菜" "𦰶" "𦵫" "𦳕" "䔫" "蓱" "蓳" "蔖" "𧏊" "蕤" "𦼬" "䕝" "䕡" "𦾱" "𧃒" "䕫" "虐" "虜" "虧" "虩" "蚩" "蚈" "蜎" "蛢" "蝹" "蜨" "蝫" "螆" t "蟡" "蠁" "䗹" "衠" "衣" "𧙧" "裗" "裞" "䘵" "裺" "㒻" "𧢮" "𧥦" "䚾" "䛇" "誠" "諭" "變" "豕" "𧲨" "貫" "賁" "贛" "起" "𧼯" "𠠄" "跋" "趼" "跰" "𠣞" "軔" "輸" "𨗒" "𨗭" "邔" "郱" "鄑" "𨜮" "鄛" "鈸" "鋗" "鋘" "鉼" "鏹" "鐕" "𨯺" "開" "䦕" "閷" "𨵷" "䧦" "雃" "嶲" "霣" "𩅅" "𩈚" "䩮" "䩶" "韠" "𩐊" "䪲" "𩒖" "頋" "頋"] #^^[3 195072 "頩" "𩖶" "飢" "䬳" "餩" "馧" "駂" "駾" "䯎" "𩬰" "鬒" "鱀" "鳽" "䳎" "䳭" "鵧" "𪃎" "䳸" "𪄅" "𪈎" "𪊑" "麻" "䵖" "黹" "黾" "鼅" "鼏" "鼖" "鼻" "𪘀" t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] t t t t t t t t t t #^^[3 196480 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t]]] #^^[1 196608 nil #^^[2 200704 nil nil nil nil nil nil #^^[3 201472 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] #^^[2 204800 nil nil nil nil nil nil nil #^^[3 205696 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] t t t t t t t t t t t t t t t t t t t t t t t t] t t t t t t t t t t t t #^^[2 258048 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t #^^[3 262016 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t]]] #^^[1 262144 t t t t t t t t t t t t t t t #^^[2 323584 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t #^^[3 327552 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t]]] #^^[1 327680 t t t t t t t t t t t t t t t #^^[2 389120 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t #^^[3 393088 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t]]] #^^[1 393216 t t t t t t t t t t t t t t t #^^[2 454656 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t #^^[3 458624 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t]]] #^^[1 458752 t t t t t t t t t t t t t t t #^^[2 520192 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t #^^[3 524160 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t]]] #^^[1 524288 t t t t t t t t t t t t t t t #^^[2 585728 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t #^^[3 589696 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t]]] #^^[1 589824 t t t t t t t t t t t t t t t #^^[2 651264 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t #^^[3 655232 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t]]] #^^[1 655360 t t t t t t t t t t t t t t t #^^[2 716800 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t #^^[3 720768 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t]]] #^^[1 720896 t t t t t t t t t t t t t t t #^^[2 782336 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t #^^[3 786304 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t]]] #^^[1 786432 t t t t t t t t t t t t t t t #^^[2 847872 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t #^^[3 851840 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t]]] #^^[1 851968 t t t t t t t t t t t t t t t #^^[2 913408 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t #^^[3 917376 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t]]] #^^[1 917504 #^^[2 917504 #^^[3 917504 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t] t ignored #^^[3 917888 ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored ignored t t t t t t t t t t t t t t t t] t t t t t t t t t t t t t t t t t t t t t t t t t t t t] t t t t t t t t t t t t t t #^^[2 978944 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t #^^[3 982912 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t]]] #^^[1 983040 t t t t t t t t t t t t t t t #^^[2 1044480 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t #^^[3 1048448 t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t t]]] nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil])

(provide 'idna-mapping)

;; Local Variables:
;; version-control: never
;; no-byte-compile: t
;; no-update-autoloads: t
;; coding: utf-8-emacs-unix
;; End:

;;; idna-mapping.el ends here
